package ru.crystals.api.examples;

import javax.annotation.PostConstruct;
import org.slf4j.Logger;
import ru.crystals.pos.api.ext.loyal.dto.AdvertisingAction;
import ru.crystals.pos.api.plugin.AdvertisingActionConditionPlugin;
import ru.crystals.pos.spi.annotation.Inject;
import ru.crystals.pos.spi.annotation.POSPlugin;
import ru.crystals.pos.spi.receipt.Receipt;

/**
 * Простейший пример плагина условия рекламной акции.<br>
 * Плагин разрешает применение рекламной акции при наличии карты в чеке и запрещает в противном случае.
 */
@POSPlugin(id="ru.crystals.api.example.advertising.action.condition.plugin")
public class AdvertisingActionConditionExample implements AdvertisingActionConditionPlugin {


    @Inject
    private Logger logger;

    @PostConstruct
    public void init() {
        logger.info("{} started", this.getClass());
    }

    @Override
    public void onDiscountCalculationStarted(Receipt receipt) {
        logger.info("onDiscountCalculationStarted called");
    }

    @Override
    public boolean isConditionExecuted(AdvertisingAction action, Receipt receipt) {
        logger.info("isConditionExecuted called");
        if(receipt.getCards().isEmpty()) {
            logger.info("No cards in the receipt {}, Advertising action \"{}\" will not be applied",
                    receipt.getNumber(), action.getName());
            // Исключительно для солидности и создания иллюзии напряженной работы сделаем задержку в две секунды.
            // Вам нет нужды вызывать искуственную задержку работы на реальных плагинах.
            try {
                Thread.sleep(2_000);
            } catch (InterruptedException iex) {
                //
            }
            return false;
        }
        logger.info("Action \"{}\" allowed", action.getName());
        return true;
    }

    @Override
    public void onDiscountCalculationFinished(Receipt receipt) {
        logger.info("onDiscountCalculationFinished called");
    }
}
