package ru.crystals.pos.api.ext.loyal.dto;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * Описывает результат обработки плагинами лояльности события окончательного расчета скидок.<br>
 * На этом этапе плагины лояльности могут подкорректировать у карт доступные потолки списания.
 * @since 0.0.39
 */
public class PostDiscountResult {

    /**
     * Хранит измененные потолки списания по картам.
     * Ключом служит номер карты, значением - потолок списания. Допустимо хранить null в качестве значения.
     */
    private Map<String, BigDecimal> bonusWriteOffLimits;

    /**
     * Возвращает мапу исправленных плагином потолков списания бонусов карт.<br>
     * Ключом в мапе служит номер карты, значением - максимально допустимая величина списания бонусов по данной карте.
     * @return  мапа максимальных величин списания бонусов по картам или пустая мапа, если таких нет.
     */
    public Map<String, BigDecimal> getBonusWriteOffLimits() {
        if(bonusWriteOffLimits == null) {
            bonusWriteOffLimits = new HashMap<>();
        }
        return bonusWriteOffLimits;
    }

    @Override
    public String toString() {
        return "PostDiscountResult{" +
                "bonusWriteOffLimits=" + bonusWriteOffLimits +
                '}';
    }
}
