package ru.crystals.pos.spi;

import java.util.concurrent.ExecutorService;
import org.slf4j.Logger;
import ru.crystals.pos.spi.equipment.SetApiPrinter;
import ru.crystals.pos.spi.ui.UIForms;

/**
 * Интерфейс фасада для взаимодействия с сервисами кассы.
 * 
 * <p>
 * Фасад может быть внедрен в поле класса плагина.
 * <h3>Пример:</h3>
 * 
 * <pre>
 * &#064;POSPlugin(id = "foo.plugin")
 * public class FooPlugin implements PaymentPlugin {
 * 
 *     &#064;Inject
 *     private Facade facade;
 * 
 *     private void someMethod() {
 *         System.out.println(facade.getPOSinfo().getShopName());
 *     }
 * 
 * }
 * </pre>
 * @deprecated используйте элементы фасада по отдельности
 */
@Deprecated
public interface Facade extends Injectable {

    /**
     * Сервис логирования.
     * <p>
     * Интерфейс также доступен для внедрения в поля плагина.
     * 
     * <h3>Пример:</h3>
     * 
     * <pre>
     * &#064;POSPlugin(id = "foo.plugin")
     * public class FooPlugin implements PaymentPlugin {
     * 
     *     &#064;Inject
     *     private Logger log;
     * 
     *     private void someMethod() {
     *         log.trace("entering in someMethod");
     *     }
     * 
     * }
     * </pre>
     * 
     * @return {@linkplain Logger}
     */
    Logger getLogger();

    /**
     * Сервис для работы c потоками.
     * 
     * <p>
     * Интерфейс также доступен для внедрения в поля плагина.
     * 
     * @return {@linkplain ExecutorService}
     */
    ExecutorService getExecutor();

    /**
     * Сервис для получения информации о кассе.
     * 
     * @return {@linkplain POSInfo}
     */
    POSInfo getPOSinfo();

    /**
     * Сервис для взаимодействия с графическим интерфейсом кассы
     * (пользователем).
     * 
     * @return {@linkplain UIForms}
     */
    UIForms getForms();

    /**
     * "Сервис" для взаимодействия с фискальным принтером
     *
     * @return {@linkplain SetApiPrinter}
     */
    SetApiPrinter getPrinter();
}
