package ru.crystals.pos.spi;

import ru.crystals.pos.api.plugin.user.User;

/**
 * Интерфейс для получения информации о кассе.
 * 
 **/
public interface POSInfo extends Injectable {

    /**
     * Номер магазина в котором работает касса.
     * 
     * @return номер магазина в диапазоне [1..99999]
     */
    int getShopNumber();

    /**
     * Номер кассы в магазине.
     * 
     * @return номер кассы в диапазоне [1..999]
     */
    int getPOSNumber();

    /**
     * Получает номер текущей смены.
     * @return номер текущей смены.
     */
    int getShiftNumber();

    /**
     * Получить наименование магазина.
     * 
     * @return наименование магазина
     */
    String getShopName();

    /**
     * Получить информацию о текущем пользователе
     * @return данные о пользователе
     */
    User getUser();

    /**
     * Получить тип кассы.
     * @return тип кассы.
     * @since 0.0.46
     */
    POSType getPOSType();

    /**
     * Возврашает идентификатор шаблона кассы.<br>
     * Под шаблоном кассы понимается касса с выделенным функционалом - касса продажи алкоголя, касса возвратов, касса в линейке, etc.
     * Шаблоны касс заводятся и настраиваются пользователем, посему могут иметь любое название и конфигурацию. Однака каждый такой шаблон
     * имеет свой уникальный идентификатор, который и возвращается этим методом.
     * @return идентификатор шаблона кассы.
     * @since 0.0.46
     */
    long getPOSTemplateGuid();

    /**
     * Возвращает текущий режим работы кассы. Под режимом понимается продажа товара, возврат по чеку, произвольный возврат, etc.
     * @return режим работы кассы.
     * @since 0.0.46
     */
    PosOperationMode getOperationMode();
}
