package ru.crystals.pos.spi;

/**
 * Интерфейс для чтения строк из файлов локализации.<br>
 * <h3>Требования к файлам:</h3>
 * <pre>
 * Формат имен XML Файлов с локализованными строками:
 *   strings_[locale].xml
 *   
 * В Set Retail 10 используются два языка: русский и английский.
 * 
 * Необходимо наличие двух файлов:
 *   strings_ru.xml - для русского языка
 *   strings_en.xml - для английского языка
 *   
 *   
 * Файлы должны иметь кодировку UTF-8:
 *  <i>{@code <?xml version="1.0" encoding="UTF-8"?>}</i>
 *  
 * Схема документа:
 *  <i>{@code <!DOCTYPE properties SYSTEM "http://java.sun.com/dtd/properties.dtd">}</i>
 *  
 * Файлы должны находится в корне jar файла плагина.
 * </pre>
 * 
 * <h3>Пример файла strings_ru.xml:</h3>
 * <pre>
 *  {@code
 *  <?xml version="1.0" encoding="UTF-8"?>
 *   <!DOCTYPE properties SYSTEM "http://java.sun.com/dtd/properties.dtd">
 *   <properties>
 *       <entry key="input.card.number.caption">Введите номер карты</entry>
 *       <entry key="server.connecting">Выполняется обращение к серверу...</entry>
 *   </properties>
 *  }
 *  </pre>
 */
public interface ResBundle extends Injectable {
   
    /**
     * Чтение строки из файла локализации.<br>
     * Используется текущий, выбранный язык в Set Retail 10.
 
     * @param key ключ параметра
     * @return Локализованная строка.<br> 
     * Если строка не найдена, будет возвращено значение ключа, т.е. переданный аргумент.
     */
    String getString(String key);

}
